Charlatan: Fixtures Made Easy
=============================

.. image:: https://travis-ci.org/uber/charlatan.png?branch=master
    :target: https://travis-ci.org/uber/charlatan

.. image:: https://coveralls.io/repos/uber/charlatan/badge.png
  :target: https://coveralls.io/r/uber/charlatan

**Efficiently manage and install data fixtures**

`Charlatan` is a library that you can use in your tests to create database
fixtures. Its aim is to provide a pragmatic interface that focuses on making it
simple to define and install fixtures for your tests. It is also agnostic in so
far as even though it's designed to work out of the box with SQLAlchemy models,
it can work with pretty much anything else.

Documentation
-------------

Latest documentation:
`charlatan.readthedocs.org/en/latest/ <https://charlatan.readthedocs.org/en/latest/>`_

Installation
------------

Using `pip`::

    $ pip install charlatan

License
-------

charlatan is available under the MIT License.

Copyright Uber 2013, Charles-Axel Dein <charles@uber.com>

Authors
-------

Charles-Axel Dein <charles@uber.com>
Erik Formella <erik@uber.com>
